@@ -34,13 +34,15 @@ public:
            const string &bedFile, const string &fastaOutFile,
            bool useFasta, bool useStrand, 
            bool useBlocks, bool useFullHeader,
-           bool useBedOut, bool useName, bool useNamePlus);
+           bool useBedOut, bool useName, 
+           bool useNamePlus, bool useNameOnly,
+           bool isRNA);
 
     // destructor
     ~Bed2Fa(void);
 
-    void ExtractDNA();
-    void ReportDNA(const BED &bed, string &dna);
+    void ExtractSeq();
+    void ReportSeq(const BED &bed, string &seq);
 
 
 private:
@@ -56,6 +58,8 @@ private:
     bool _useBedOut;    // priginal BED records followed by FASTA on same line
     bool _useName;
     bool _useNamePlus;
+    bool _useNameOnly;
+    bool _isRNA;
 
     // instance of a bed file class.
     BedFile  *_bed;
