@@ -28,29 +28,22 @@ bool Bed3Interval::initFromFile(SingleLineDelimTextFileReader *fileReader)
 	fileReader->getField(2, _endPosStr);
 	_startPos = str2chrPos(_startPosStr);
 	_endPos = str2chrPos(_endPosStr);
+	_zeroLength = false;
 	return true;
 }
 
-void Bed3Interval::print(string &outBuf) const
-{
-	ostringstream s;
-	s << _chrName;
-	s << "\t";
-	s << _startPos;
-	s << "\t";
-	s << _endPos;
-	outBuf.append(s.str());
+inline void print_record(const string& name, CHRPOS start, CHRPOS end, string& buf) {
+	static char buffer[1024];
+	snprintf(buffer, sizeof(buffer), "%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS, name.c_str(), start, end);
+	buf.append(buffer);
 }
 
-void Bed3Interval::print(string &outBuf, int start, int end) const
-{
-	ostringstream s;
-	s << _chrName;
-	s << "\t";
-	s << start;
-	s << "\t";
-	s << end;
-	outBuf.append(s.str());
+void Bed3Interval::print(string &outBuf) const{
+	print_record(_chrName, _startPos, _endPos, outBuf);
+}
+
+void Bed3Interval::print(string &outBuf, CHRPOS start, CHRPOS end) const{
+	print_record(_chrName, start, end, outBuf);
 }
 
 void Bed3Interval::print(string &outBuf, const string & start, const string & end) const
