@@ -21,22 +21,20 @@ bool Bed5Interval::initFromFile(SingleLineDelimTextFileReader *fileReader)
 	return baseRetFlag;
 }
 
+inline void print_record(const string& chrom_name, CHRPOS start, CHRPOS end, const string& name, const string& score, string& buf) {
+	static char buffer[1024];
+	snprintf(buffer, sizeof(buffer), "%s\t%" PRId_CHRPOS "\t%" PRId_CHRPOS"\t%s\t%s", chrom_name.c_str(), start, end, name.c_str(), score.c_str());
+	buf.append(buffer);
+}
+
 void Bed5Interval::print(string &outBuf) const
 {
-	Bed3Interval::print(outBuf);
-	outBuf.append("\t");
-	outBuf.append(_name);
-	outBuf.append("\t");
-	outBuf.append(_score);
+	print_record(_chrName, _startPos, _endPos, _name, _score, outBuf);
 }
 
 void Bed5Interval::print(string &outBuf, CHRPOS start, CHRPOS end) const
 {
-	Bed3Interval::print(outBuf, start, end);
-	outBuf.append("\t");
-	outBuf.append(_name);
-	outBuf.append("\t");
-	outBuf.append(_score);
+	print_record(_chrName, start, end, _name, _score, outBuf);
 }
 
 void Bed5Interval::print(string &outBuf, const string & start, const string & end) const
