@@ -9,10 +9,12 @@
 #define RECORD_H_
 
 #include <string>
+#include "BedtoolsTypes.h"
 #include "FreeList.h"
 #include "string.h"
 #include "FileRecordTypeChecker.h"
 
+
 using namespace std;
 
 class FileRecordMgr;
@@ -33,7 +35,7 @@ public:
 	virtual bool initFromFile(FileReader *) =0;
 	virtual void clear();
 	virtual void print(string &) const {}
-	virtual void print(string &, int, int ) const {}
+	virtual void print(string &, CHRPOS, CHRPOS ) const {}
 	virtual void print(string &, const string &, const string &) const {}
 	virtual void print(FILE *fp, bool newline = false) const;
 	virtual void printNull(string &) const {}
@@ -56,13 +58,13 @@ public:
 	virtual int getChromId() const { return _chrId; }
 	virtual void setChromId(int id) { _chrId = id; }
 
-	virtual int getStartPos() const { return _startPos; }
-	virtual void setStartPos(int startPos) { _startPos = startPos; }
+	virtual CHRPOS getStartPos() const { return _startPos; }
+	virtual void setStartPos(CHRPOS startPos) { _startPos = startPos; }
 	virtual const string &getStartPosStr() const { return _startPosStr; }
 	virtual void setStartPosStr(const string &str) { _startPosStr = str; }
 
-	virtual int getEndPos() const { return _endPos; }
-	virtual void setEndPos(int endPos) { _endPos = endPos; }
+	virtual CHRPOS getEndPos() const { return _endPos; }
+	virtual void setEndPos(CHRPOS endPos) { _endPos = endPos; }
 	virtual const string &getEndPosStr() const { return _endPosStr; }
 	virtual void setEndPosStr(const string &str) { _endPosStr = str; }
 
@@ -70,7 +72,8 @@ public:
 	virtual void setZeroLength(bool val) { _zeroLength = val; }
 
 	virtual const string &getStrand() const { return _strand; }
-	virtual void setStrand(const string &val) { _strand = val;
+	virtual void setStrand(const string &val) {
+		_strand = val;
 		_strandVal = (val == "+" ? FORWARD : (val == "-" ? REVERSE : UNKNOWN));
 	}
 	virtual void setStrand(char val) { _strand = val;
@@ -135,7 +138,8 @@ public:
 							float overlapFractionA,
 							float overlapFractionB,
 							bool reciprocalFraction,
-						    bool eitherFraction) const;
+						    bool eitherFraction,
+						    bool obeySplits) const;
 
 	// *** WARNING !!! ** sameChromIntersects is a faster version of the intersects method,
 	// BUT the caller MUST ensure that the records are on the same
@@ -146,13 +150,14 @@ public:
 									 float overlapFractionA,
 									 float overlapFractionB,
 									 bool reciprocalFraction,
-									 bool eitherFraction) const;
+									 bool eitherFraction,
+									 bool obeySplits) const;
 
 //	virtual static bool isNumericField(int fieldNum) const = 0;
 
 	bool hasChrInChromName() const;
 	bool hasLeadingZeroInChromName(bool chrKnown = false) const;
-	virtual int getLength(bool obeySplits) const;
+	virtual CHRPOS getLength(bool obeySplits) const;
 
 	void setFileRecordManager(FileRecordMgr *frm);
 	FileRecordMgr * getFileRecordManager();
@@ -165,8 +170,8 @@ protected:
 	int _fileIdx; //associated file the record came from
 	string _chrName;
 	int _chrId;
-	int _startPos;
-	int _endPos;
+	CHRPOS _startPos;
+	CHRPOS _endPos;
 	//It is actually faster to also store the start and end positions as their original strings than to
 	//have to convert their integer representations back to strings when printing them.
 	string _startPosStr;
