@@ -12,6 +12,7 @@
 #include "NewGenomeFile.h"
 #include "ParseTools.h"
 #include "Tokenizer.h"
+#include <fstream>
 
 NewGenomeFile::NewGenomeFile(const string &genomeFilename)
 : _maxId(-1)
@@ -46,22 +47,29 @@ NewGenomeFile::~NewGenomeFile(void) {
 
 void NewGenomeFile::loadGenomeFileIntoMap() {
 
-
-	ifstream genFile(_genomeFileName.c_str());
-	if (!genFile.good()) {
-		cerr << "Error: Can't open genome file" << _genomeFileName << "Exiting..." << endl;
-		exit(1);
+	if (_genomeFileName == "-" || _genomeFileName == "stdin")
+	{
+		_genomeFile = &cin;
 	}
-	string sLine;
+	else
+	{
+		_genomeFile = new ifstream(_genomeFileName.c_str(), ios::in);
+		if (!_genomeFile->good()) 
+		{
+			cerr << "Error: Can't open genome file" << _genomeFileName << "Exiting..." << endl;
+			exit(1);
+		}
+	}
+
+	string line;
 	Tokenizer fieldTokens;
 	CHRPOS chrSize = 0;
+	_genomeLength = 0;
 	string chrName;
-	while (!genFile.eof()) {
-		sLine.clear();
+	while (getline(*_genomeFile, line)) {
 		chrSize = 0;
 		chrName.clear();
-		getline(genFile, sLine);
-		int numFields = fieldTokens.tokenize(sLine.c_str());
+		int numFields = fieldTokens.tokenize(line.c_str());
 
 		// allow use of .fai files.
 		if (numFields < 2) {
@@ -69,6 +77,13 @@ void NewGenomeFile::loadGenomeFileIntoMap() {
 		}
 		chrName = fieldTokens.getElem(0);
 		chrSize = str2chrPos(fieldTokens.getElem(1));
+		if (chrSize == 0) {
+			cerr << "Error: " 
+			     << chrName 
+			     << " has length equal to 0. Each chromosome must have non-zero length. Exiting." 
+			     << endl;
+			exit(1);
+		}
 		_maxId++;
 		_chromSizeIds[chrName] = pair<CHRPOS, int>(chrSize, _maxId);
 		_startOffsets.push_back(_genomeLength);
@@ -76,7 +91,7 @@ void NewGenomeFile::loadGenomeFileIntoMap() {
 		_chromList.push_back(chrName);
 	}
 	if (_maxId == -1) {
-		cerr << "Error: The genome file " << _genomeFileName << " has no valid entries. Exiting." << endl;
+		cerr << "Error: The genome file " << _genomeFileName << " has no valid entries (are you sure it's a 2-column bedtools genome file). Exiting." << endl;
 		exit(1);
 	}
 	// Special: BAM files can have unmapped reads, which show as no chromosome, or an empty chrom string.
@@ -88,7 +103,6 @@ void NewGenomeFile::loadGenomeFileIntoMap() {
 
 	_startOffsets.push_back(_genomeLength); //insert the final length as the last element
 	//to help with the lower_bound call in the projectOnGenome method.
-	genFile.close();
 }
 
 bool NewGenomeFile::projectOnGenome(CHRPOS genome_pos, string &chrom, CHRPOS &start) {
@@ -100,7 +114,7 @@ bool NewGenomeFile::projectOnGenome(CHRPOS genome_pos, string &chrom, CHRPOS &st
     // use the iterator to identify the appropriate index 
     // into the chrom name and start vectors
     CHRPOS i = CHRPOS(low-_startOffsets.begin());
-    if (i >= _chromList.size()) {
+    if (i >= (CHRPOS)_chromList.size()) {
     	return false; //position not on genome
     }
     chrom = _chromList[i - 1];
@@ -135,7 +149,7 @@ CHRPOS NewGenomeFile::getChromSize(const string &chrom) const {
     return INT_MAX;
 }
 
-CHRPOS NewGenomeFile::getChromId(const string &chrom) {
+uint32_t NewGenomeFile::getChromId(const string &chrom) {
 	if (chrom == _currChromName) {
 		return _currChromId;
 	}
