@@ -65,14 +65,22 @@ void RecordOutputMgr::init(ContextBase *context) {
 		_bamWriter->SetCompressionMode(_context->getUncompressedBam() ?  BamTools::BamWriter::Uncompressed : BamTools::BamWriter::Compressed);
 
 		int bamFileIdx = _context->getBamHeaderAndRefIdx();
-		_bamWriter->Open("stdout", _context->getFile(bamFileIdx)->getHeader().c_str(), _context->getFile(bamFileIdx)->getBamReferences());
+
+		if(!_context->isCram())
+			_bamWriter->Open("stdout", _context->getFile(bamFileIdx)->getHeader().c_str(), _context->getFile(bamFileIdx)->getBamReferences());
+		else
+			_bamWriter->Open("stdout", _context->getFile(bamFileIdx)->getHeader().c_str(), 
+					                   _context->getFile(bamFileIdx)->getBamReferences(), 
+									   _context->getFile(bamFileIdx)->getCramRefs());
 	} else {
 		//for everything but BAM, we'll copy output to an output buffer before printing.
 		_outBuf.reserve(MAX_OUTBUF_SIZE);
 	}
 	if (_context->getProgram() == ContextBase::INTERSECT) {
-		if ((static_cast<ContextIntersect *>(_context))->getAnyHit() || (static_cast<ContextIntersect *>(_context))->getNoHit() ||
-				(static_cast<ContextIntersect *>(_context))->getWriteCount()) {
+		if ((static_cast<ContextIntersect *>(_context))->getAnyHit() || 
+			(static_cast<ContextIntersect *>(_context))->getNoHit() ||
+			(static_cast<ContextIntersect *>(_context))->getWriteCount() ||
+			(static_cast<ContextIntersect *>(_context))->getWriteCountsPerDatabase()) {
 			_printable = false;
 		}
 	}
@@ -144,7 +152,7 @@ void RecordOutputMgr::printRecord(Record *record, const string & value)
 	if (needsFlush()) flush();
 }
 
-void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *dists) {
+void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<CHRPOS> *dists) {
 
 	//The first time we print a record is when we print any header, because the header
 	//hasn't been read from the query file until after the first record has also been read.
@@ -159,8 +167,21 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 		_currBamBlockList = &blockList;
 	}
 	if (!keyList.empty()) {
+		if (context->getNumClosestHitsWanted() > keyList.size()) 
+		{
+			cerr << "Warning: Fewer hits ("
+			     << keyList.size()
+			     << ") found on " 
+			     << keyRec->getChrName() 
+			     << " than requested ("
+			     << context->getNumClosestHitsWanted()
+			     << "). It is likely that there are fewer total records"
+			     << " on that chromosome than requested." 
+			     << endl;
+		}		
 		int distCount = 0;
-		for (RecordKeyVector::iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next()) {
+		for (RecordKeyVector::iterator_type iter = keyList.begin(); iter != keyList.end(); iter = keyList.next())
+		{
 			const Record *hitRec = *iter;
 			printKey(keyRec, keyRec->getStartPosStr(), keyRec->getEndPosStr());
 			tab();
@@ -168,7 +189,7 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 			printKey(hitRec, hitRec->getStartPosStr(), hitRec->getEndPosStr());
 			if (dists != NULL) {
 				tab();
-				int dist = (*dists)[distCount];
+				CHRPOS dist = (*dists)[distCount];
 				//if not using sign distance, use absolute value instead.
 				dist = context->signDistance() ? dist : abs(dist);
 				ostringstream s;
@@ -190,7 +211,6 @@ void RecordOutputMgr::printClosest(RecordKeyVector &keyList, const vector<int> *
 		null(false, true);
 		if (context->reportDistance()) {
 			tab();
-
 			_outBuf.append("-1");
 		}
 		newline();
@@ -344,9 +364,9 @@ void RecordOutputMgr::reportOverlapDetail(const Record *keyRecord, const Record
 {
 
 	// overlap interval is defined by min(e1,e2) - max(s1,s2)
-	int maxStart = max(keyRecord->getStartPos(), hitRecord->getStartPos());
+	CHRPOS maxStart = max(keyRecord->getStartPos(), hitRecord->getStartPos());
 	//cout << keyRecord->getStartPos() << "," << hitRecord->getStartPos();
-	int minEnd = min(keyRecord->getEndPos(), hitRecord->getEndPos());
+	CHRPOS minEnd = min(keyRecord->getEndPos(), hitRecord->getEndPos());
 
 	// need to undo our conversion of 1-based start coordinates to 0-based
 	if (!keyRecord->isZeroBased())
@@ -427,7 +447,34 @@ void RecordOutputMgr::reportOverlapSummary(RecordKeyVector &keyList)
 		int2str(numOverlapsFound, _outBuf, true);
 		newline();
 		if (needsFlush()) flush();
-	} else if ((static_cast<ContextIntersect *>(_context))->getNoHit() && numOverlapsFound == 0) {
+	} 
+	else if ((static_cast<ContextIntersect *>(_context))->getWriteCountsPerDatabase()) {
+		// build a map of the hit counts per database
+		map<int, int> db_counts; 
+		// initialize to 0 for all files (-A is file 0)
+		for (size_t i = 1; i < _context->getNumInputFiles(); i++)
+		{
+			db_counts[i] = 0;
+		}
+		// tally hits per database
+		for (auto & hit : keyList) {
+			db_counts[hit->getFileIdx()]+=1;
+		}
+
+		// report A with a separate line for each db and its hit count
+		for (auto it=db_counts.begin(); it!=db_counts.end(); ++it)
+		{
+			if (printKeyAndTerminate(keyList)) {
+				return;
+			}
+			tab();
+			addDbFileId(it->first);
+			int2str(it->second, _outBuf, true);
+			newline();
+		}
+		if (needsFlush()) flush();
+	}
+	else if ((static_cast<ContextIntersect *>(_context))->getNoHit() && numOverlapsFound == 0) {
 		if (printKeyAndTerminate(keyList)) {
 			return;
 		}
@@ -507,6 +554,7 @@ void RecordOutputMgr::null(bool queryType, bool dbType)
 		(static_cast<GffRecord *>(dummyRecord))->setNumFields((static_cast<ContextIntersect *>(_context))->getMaxNumDatabaseFields());
 		break;
 	default:
+		dummyRecord = new Bed3Interval();
 		break;
 	}
 	if (dummyRecord) {
@@ -524,7 +572,7 @@ void RecordOutputMgr::printKey(const Record *key, const string & start, const st
 	}
 }
 
-void RecordOutputMgr::printKey(const Record *key, int start, int end)
+void RecordOutputMgr::printKey(const Record *key, CHRPOS start, CHRPOS end)
 {
 	if (key->getType() != FileRecordTypeChecker::BAM_RECORD_TYPE) {
 		key->print(_outBuf, start, end);
