@@ -5,14 +5,12 @@ FAILURES=0;
 
 check()
 {
-	if diff $1 $2; then
-    	echo ok
-
-	else
-    	FAILURES=$(expr $FAILURES + 1);
-		echo fail
-
-	fi
+     if diff $1 $2; then
+          echo ok
+     else
+          FAILURES=$(expr $FAILURES + 1);
+          echo fail
+     fi
 }
 
 
@@ -119,3 +117,34 @@ $BT complement -i <(echo -e "chr1\t90\t110") \
 check obs exp
 rm obs exp
 [[ $FAILURES -eq 0 ]] || exit 1;
+
+###########################################################
+# -L only reports chroms that were in the BED file.
+###########################################################
+echo -e "    complement.t9...\c"
+echo "chr1	0	1
+chr1	500	900
+chr1	950	1000" > exp
+$BT complement -i issue_503.bed \
+               -g issue_503.genome \
+               -L \
+               > obs
+check obs exp
+rm obs exp
+
+###########################################################
+# Now, without -L
+###########################################################
+echo -e "    complement.t10...\c"
+echo "chr1	0	1
+chr1	500	900
+chr1	950	1000
+chr2	0	1000
+chr3	0	1000" > exp
+$BT complement -i issue_503.bed \
+               -g issue_503.genome \
+               > obs
+check obs exp
+rm obs exp
+
+[[ $FAILURES -eq 0 ]] || exit 1;
