@@ -139,24 +139,61 @@ $BT getfasta -fi t.fa -bed blocks.bed > obs
 check obs exp
 rm obs exp
 
-echo -e "    getfasta.t12...\c"
-echo ">three_blocks_match
+echo -e "    getfasta.t12a...\c"
+echo ">three_blocks_match::chr1:0-40
 agggggggggcgggggggggtgggggggggaggggggggg
->three_blocks_match
+>three_blocks_match::chr1:0-40
 agggggggggcgggggggggtgggggggggaggggggggg" > exp
 $BT getfasta -fi t.fa -bed blocks.bed -name > obs
 check obs exp
 rm obs exp
 
-echo -e "    getfasta.t13...\c"
-echo ">three_blocks_match(+)
+echo -e "    getfasta.t12a...\c"
+echo ">three_blocks_match::chr1:0-40
 agggggggggcgggggggggtgggggggggaggggggggg
->three_blocks_match(-)
+>three_blocks_match::chr1:0-40
+agggggggggcgggggggggtgggggggggaggggggggg" > exp
+$BT getfasta -fi t.fa -bed blocks.bed -name+ > obs
+check obs exp
+rm obs exp
+
+echo -e "    getfasta.t12b...\c"
+echo ">three_blocks_match
+agggggggggcgggggggggtgggggggggaggggggggg
+>three_blocks_match
+agggggggggcgggggggggtgggggggggaggggggggg" > exp
+$BT getfasta -fi t.fa -bed blocks.bed -nameOnly > obs
+check obs exp
+rm obs exp
+
+echo -e "    getfasta.t13a...\c"
+echo ">three_blocks_match::chr1:0-40(+)
+agggggggggcgggggggggtgggggggggaggggggggg
+>three_blocks_match::chr1:0-40(-)
 ccccccccctcccccccccacccccccccgccccccccct" > exp
 $BT getfasta -fi t.fa -bed blocks.bed -name -s > obs
 check obs exp
 rm obs exp
 
+echo -e "    getfasta.t13b...\c"
+echo ">three_blocks_match::chr1:0-40(+)
+agggggggggcgggggggggtgggggggggaggggggggg
+>three_blocks_match::chr1:0-40(-)
+ccccccccctcccccccccacccccccccgccccccccct" > exp
+$BT getfasta -fi t.fa -bed blocks.bed -name+ -s > obs
+check obs exp
+rm obs exp
+
+echo -e "    getfasta.t13c...\c"
+echo ">three_blocks_match(+)
+agggggggggcgggggggggtgggggggggaggggggggg
+>three_blocks_match(-)
+ccccccccctcccccccccacccccccccgccccccccct" > exp
+$BT getfasta -fi t.fa -bed blocks.bed -nameOnly -s > obs
+check obs exp
+rm obs exp
+
+
 echo -e "    getfasta.t14...\c"
 echo ">three_blocks_match::chr1:0-40
 agggggggggcgggggggggtgggggggggaggggggggg
@@ -182,3 +219,23 @@ $BT getfasta -fi t.fa -bed <(echo -e "chr1\t0\t1") > obs
 check obs exp
 rm obs exp
 [[ $FAILURES -eq 0 ]] || exit 1;
+
+echo -e "    getfasta.t16..\c"
+echo ">candidate_1::chr1:0-10(-)
+catcggtcaa
+>candidate_2::chr1:0-10(+)
+uugaccgaug" > exp
+$BT getfasta -fi rna.fasta -bed rna.bed -s -name > obs
+check obs exp
+rm obs exp
+
+echo -e "    getfasta.t17..\c"
+echo ">candidate_1::chr1:0-10(-)
+caucggucaa
+>candidate_2::chr1:0-10(+)
+uugaccgaug" > exp
+$BT getfasta -fi rna.fasta -bed rna.bed -s -name -rna > obs
+check obs exp
+rm obs exp
+
+[[ $FAILURES -eq 0 ]] || exit 1;
