@@ -467,7 +467,7 @@ chr1	30	100	.,.,.
 chr2	10	20	.
 chr2	30	40	.
 chr2	42	100	.,." >exp
-../../bin/bedtools merge -i a.full.bam  -c 7 -o collapse > obs
+$BT merge -i a.full.bam  -c 7 -o collapse > obs
 check exp obs
 rm obs exp
 
